/*********************************************************************
 *
 *                Microchip USB C18 Firmware Version 1.0
 *
 *********************************************************************
 * FileName:        main.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the CompanyE for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS ISECONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       11/19/04    Original.
 ********************************************************************/

/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"                        // Required
#include "system\usb\usb.h"                         // Required
#include "io_cfg.h"                                 // Required

#include "system\usb\usb_compile_time_validation.h" // Optional
#include "user\user.h" 	                         // Modifiable
#include "autofiles\usbcfg.h"

/** V A R I A B L E S ********************************************************/
#pragma udata

extern byte active_protocol;

/** P R I V A T E  P R O T O T Y P E S ***************************************/
static void InitializeSystem(void);
void USBTasks(void);

/** V E C T O R  R E M A P P I N G *******************************************/

/** D E C L A R A T I O N S **************************************************/
#pragma code
/******************************************************************************
 * Function:        void main(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Main program entry point.
 *
 * Note:            None
 *****************************************************************************/
void main(void)
{
    InitializeSystem();
    while(1)
    {
        USBTasks();         // USB Tasks
        ProcessIO();        // See user\user.c & .h
    }//end while
}//end main

/******************************************************************************
 * Function:        static void InitializeSystem(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        InitializeSystem is a centralize initialization routine.
 *                  All required USB initialization routines are called from
 *                  here.
 *
 *                  User application initialization routine should also be
 *                  called from here.                  
 *
 * Note:            None
 *****************************************************************************/
static void InitializeSystem(void)
{
	UCFG = _PUEN|_TRINT|_FS|_PPBM1;
	// vAbvgpbgV[ogpbtXs[hbCtrlOuts|ɂ
	usb_device_state = DETACHED_STATE;	// ڑ
	usb_stat._byte = 0x00;				// [gEFCNAbvgpsE]=RAM
 	usb_active_cfg = 0;				// RtBM[Vl(cf:SET_CONFIGURATION)
	usb_alt_intf[0]= 0;				// Array to keep track of the current alternate
 	
 	active_protocol = 1;				// Report Protocol
	
	UCONbits.PPBRST=1;				// s|obt@Zbg
	ep0Bo0.Cnt = 8;
	ep0Bo0.ADR = (byte*)&SetupPkt;
	ep0Bo0.Stat._byte = _USIE;				// ZbgAbvpPbgM
	ep0Bo1.Cnt = 8;
	ep0Bo1.ADR = (byte*)&CtrlOutData;
	ep0Bo1.Stat._byte =0;					// CtrlOutNAKԂ
	ep0Bi.Cnt = 0;
	ep0Bi.ADR = (byte*)&CtrlInData;
	ep0Bi.Stat._byte = 0;					// CtrlInNAKԂ
	ep1Bi.Cnt = 0;
	ep1Bi.ADR = (byte*)&hid_report_in[0];
	ep1Bi.Stat._byte = 0;					// InterruptInNAKԂ

	UserInit();                     

}//end InitializeSystem

/******************************************************************************
 * Function:        void USBTasks(void)
 *
 * PreCondition:    InitializeSystem has been called.
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Service loop for USB tasks.
 *
 * Note:            None
 *****************************************************************************/
void USBTasks(void)
{
    /*
     * Servicing Hardware
     */
	
    USBCheckBusStatus();                    // Must use polling method
    // ڑ̏ԂȂPOWERED_STATEɂ
//    if(UCFGbits.UTEYE!=1)	//not defined
        USBDriverService();                 // Interrupt or polling method

}// end USBTasks

#pragma config PLLDIV = 1
// 4MHz/1=4MHz->96MHz PLL
#pragma config CPUDIV = OSC1_PLL2 
// 96MHz/2=48MHz->CPU
#pragma config USBDIV = 2
// 96MHz/2=48MHz->USB 

#pragma config FOSC = HS 

#pragma config FCMEN = OFF 
#pragma config IESO = OFF 

#pragma config PWRT = OFF 
#pragma config BOR = ON 
#pragma config BORV = 0
#pragma config VREGEN = ON 

#pragma config WDT = OFF 
#pragma config WDTPS = 1 

#pragma config MCLRE = ON	 	
#pragma config LPT1OSC = OFF 
#pragma config PBADEN = OFF 
#pragma config CCP2MX = ON	

#pragma config STVREN = OFF 
#pragma config LVP = OFF 	
#pragma config ICPRT = OFF		// RB67
#pragma config XINST = OFF 
#pragma config DEBUG = OFF

#pragma config CP0 = OFF 
#pragma config CPB = OFF 
#pragma config WRT0 = OFF 
#pragma config WRTB = OFF 
#pragma config EBTR0 = OFF 
#pragma config EBTRB = OFF
/** EOF main.c ***************************************************************/
